package App::GetoptLongUtils;

our $DATE = '2016-10-27'; # DATE
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: Collection of CLI utilities related to Getopt::Long

__END__

=pod

=encoding UTF-8

=head1 NAME

App::GetoptLongUtils - Collection of CLI utilities related to Getopt::Long

=head1 VERSION

This document describes version 0.004 of App::GetoptLongUtils (from Perl distribution App-GetoptLongUtils), released on 2016-10-27.

=head1 DESCRIPTION

This distribution provides the following command-line utilities related to
L<Getopt::Long>:

=over

=item * L<detect-getopt-long-script>

=item * L<dump-getopt-long-script>

=item * L<parse-getopt-long-spec>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-GetoptLongUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-GetoptLongUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-GetoptLongUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Getopt::Long>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
